@@ -81,3 +81,13 @@ def test_get_profile_json():
     response, content = http.request('http://0.0.0.0:8080/profiles/cdent',
             headers={'Accept': 'application/json'})
     assert response['status'] == '415', content
+
+def test_vcard():
+    response, content = http.request('http://0.0.0.0:8080/profiles/cdent')
+    assert response['status'] == '200'
+
+    assert '<div id="hcard-cdent" class="vcard"' in content
+    assert 'src="/recipes/cdent_public/tiddlers/SiteIcon" alt="avatar" class="photo"' in content
+    assert '<div class="fn"><a href="http://cdent.0.0.0.0:8080/" class="url">cdent</a></div>' in content
+
+
